@@ -25,12 +25,15 @@ apps_module = importlib.import_module('_apps')
 apps = getattr(apps_module, "apps")
 
 
+###################
+# URL Redirecting #
+###################
 ##
 # @desc Redirects to HTTP error pages
 # 
-# @param code: int - HTTP status code
+# @param {int} code -- The HTTP status code
 #
-# @return object
+# @return {object}
 ##
 def abort(code:int=404):
     # Return result
@@ -40,9 +43,10 @@ def abort(code:int=404):
 ##
 # @desc Redirects to relative URL
 # 
-# @param url: str
+# @param {str} url  -- The URL to redirect to
+# @param {int} code -- The HTTP status code
 #
-# @return object
+# @return {object}
 ##
 def redirect(url:str, code:int=302):
     # Return results
@@ -52,8 +56,9 @@ def redirect(url:str, code:int=302):
 ##
 # @desc Redirects to app URL
 # 
-# @param app: str - The app name
-# @param controller: str - The app controller name
+# @param {str} app        -- The app name
+# @param {str} controller -- The app controller name
+# @param {int} code       -- The HTTP status code
 #
 # @return object
 ##
@@ -65,12 +70,111 @@ def redirect_to(app:str, controller:str=None, code:int=302):
     return redirect(url=url, code=code)
 
 
+##
+# @desc Redirects not logged-in users
+#
+# @param {str}      app        -- The app name
+# @param {str}      controller -- The app controller name
+# @param {str|list} check      -- The session|cookie name(s) to check
+#
+# @var {str} next -- The next url
+# 
+# @return {object}
+##
+def login_required(app:str, controller:str=None, check:Union[str, list]='user'):
+    def wrapper(inner):
+        def decorator(*args, **kwargs):
+            # Fetch the route final url
+            url = route_url(app, controller)
+
+            # Find next URL
+            next = request.url.replace(request.url_root, '/')
+
+            # check is of type str
+            if type(check) is str:
+                # Check cookie
+                if check_cookie(check):
+                    set_session(check, get_cookie(check))
+
+                # User is logged-in
+                if check_session(check):
+                    return inner(*args, **kwargs)
+
+            # check is of type list
+            elif type(check) is list:
+                for x in check:
+                    # Check cookie
+                    if check_cookie(x):
+                        set_session(x, get_cookie(x))
+
+                    # User is logged-in
+                    if check_session(x):
+                        return inner(*args, **kwargs)
+
+            # User is not logged-in
+            # Check the language
+            if multi_lang:
+                if check_session('active_lang'):
+                    return redirect(f'''/{get_session('active_lang')}/{url}?next={next}''')
+
+            return redirect(f'{url}?next={next}')
+
+        return decorator
+    return wrapper
+
+
+##
+# @desc Redirects logged-in users
+#
+# @param {str}      app        -- The app name
+# @param {str}      controller -- The app controller name
+# @param {str|list} check      -- The session|cookie name(s) to check
+#
+# @return {object}
+##
+def login_abort(app:str, controller:str=None, check:Union[str, list]='user'):
+    def wrapper(inner):
+        def decorator(*args, **kwargs):
+            # Fetch the route final url
+            url = route_url(app, controller)
+
+            # check is of type str
+            if type(check) is str:
+                # Check cookie
+                if check_cookie(check):
+                    set_session(check, get_cookie(check))
+
+                # User is logged-in
+                if check_session(check):
+                    return redirect(url)
+
+            # check is of type list
+            elif type(check) is list:
+                for x in check:
+                    # Check cookie
+                    if check_cookie(x):
+                        set_session(x, get_cookie(x))
+
+                    # User is logged-in
+                    if check_session(x):
+                        return redirect(url)
+
+            # User is not logged-in
+            return inner(*args, **kwargs)
+
+        return decorator
+    return wrapper
+
+
+####################
+# Validating Users #
+####################
 ##
 # @desc Checks session for existence
 # 
-# @param name: str -- *Required session name
+# @param {str} name -- Required session name
 # 
-# @return bool
+# @return {bool}
 ##
 def check_session(name:str):
     # Session exists
@@ -85,9 +189,9 @@ def check_session(name:str):
 ##
 # @desc Gets session
 # 
-# @param name: str -- *Required session name
+# @param {str} name -- Required session name
 # 
-# @return object
+# @return {object}
 ##
 def get_session(name:str):
     return session[name]
@@ -96,8 +200,8 @@ def get_session(name:str):
 ##
 # @desc Sets session
 # 
-# @param name: str -- *Required session name
-# @param value: str -- *Required session value
+# @param {str} name  -- Required session name
+# @param {str} value -- Required session value
 ##
 def set_session(name:str, value:str):
     session[name] = value
@@ -106,7 +210,7 @@ def set_session(name:str, value:str):
 ##
 # @desc Unset session
 # 
-# @param name: str -- *Required session name
+# @param {str} name -- Required session name
 ##
 def unset_session(name:str):
     session.pop(name, None)
@@ -115,9 +219,9 @@ def unset_session(name:str):
 ##
 # @desc Checks cookie for existence
 # 
-# @param name: str -- *Required cookie name
+# @param {str} name -- Required cookie name
 # 
-# @return bool
+# @return {bool}
 ##
 def check_cookie(name:str):
     # Cookie exists
@@ -132,9 +236,9 @@ def check_cookie(name:str):
 ##
 # @desc Get cookie
 # 
-# @param name: str -- *Required cookie name
+# @param {str} name -- Required cookie name
 # 
-# @return object
+# @return {object}
 ##
 def get_cookie(name:str):
     return request.cookies.get(name)
@@ -143,12 +247,12 @@ def get_cookie(name:str):
 ##
 # @desc Sets cookie
 # 
-# @param name: str -- *Required cookie name
-# @param value: str -- *Required cookie value
-# @param days: int -- Optional expiry days
-# @param data: dictionary -- Optional data
+# @param {str}  name  -- Required cookie name
+# @param {str}  value -- Required cookie value
+# @param {int}  days  -- Optional expiry days
+# @param {dict} data  -- Optional data
 # 
-# @return object
+# @return {object}
 ##
 def set_cookie(name:str, value:str, data:dict={}, days:int=30):
     # Check required params
@@ -197,8 +301,8 @@ def set_cookie(name:str, value:str, data:dict={}, days:int=30):
 ##
 # @desc Unsets cookie
 # 
-# @param name: str -- *Required cookie name
-# @param data: dictionary -- Optional data
+# @param {str}  name -- Required cookie name
+# @param {dict} data -- Optional data
 ##
 def unset_cookie(name:str, data:dict={}):
     # Check required params
@@ -240,148 +344,15 @@ def unset_cookie(name:str, data:dict={}):
     return res
 
 
-##
-# @desc Finds active language
-# 
-# @var active_lang: str - The active language code
-#
-# @return str
-##
-def find_lang():
-    path = request.path
-    lang = path.split('/')[1]
-
-    # Check multi language
-    if multi_lang:
-        # Check the language path
-        if lang in languages:
-            active_lang = lang
-            LANGUAGE = '/' + active_lang
-            set_session('active_lang', lang)
-
-        elif check_cookie('active_lang'):
-            active_lang = get_cookie('active_lang')
-            LANGUAGE = '/' + active_lang
-            set_session('active_lang', get_cookie('active_lang'))
-
-        elif check_session('active_lang'):
-            active_lang = get_session('active_lang')
-            LANGUAGE = '/' + active_lang
-
-        else:
-            active_lang = default_lang
-            LANGUAGE = '/' + active_lang
-            set_session('active_lang', default_lang)
-
-    else:
-        active_lang = default_lang
-        LANGUAGE = ''
-
-    # Return result
-    return {
-        'active_language': active_lang,
-        'LANGUAGE': LANGUAGE,
-    }
-
-
-##
-# @desc Redirects not logged-in users
-#
-# @param url: str -- *Required url for users app
-#
-# @var next: str -- The next url
-# 
-# @return object
-##
-def login_required(app:str, controller:str=None, check:Union[str, list]='user'):
-    def wrapper(inner):
-        def decorator(*args, **kwargs):
-            # Fetch the route final url
-            url = route_url(app, controller)
-
-            # Find next URL
-            next = request.url.replace(request.url_root, '/')
-
-            # check is of type str
-            if type(check) is str:
-                # Check cookie
-                if check_cookie(check):
-                    set_session(check, get_cookie(check))
-
-                # User is logged-in
-                if check_session(check):
-                    return inner(*args, **kwargs)
-
-            # check is of type list
-            elif type(check) is list:
-                for x in check:
-                    # Check cookie
-                    if check_cookie(x):
-                        set_session(x, get_cookie(x))
-
-                    # User is logged-in
-                    if check_session(x):
-                        return inner(*args, **kwargs)
-
-            # User is not logged-in
-            # Check the language
-            if multi_lang:
-                if check_session('active_lang'):
-                    return redirect(f'''/{get_session('active_lang')}/{url}?next={next}''')
-
-            return redirect(f'{url}?next={next}')
-
-        return decorator
-    return wrapper
-
-
-##
-# @desc Redirects logged-in users
-#
-# @param url: str -- *Required url for app
-#
-# @return object
-##
-def login_abort(app:str, controller:str=None, check:Union[str, list]='user'):
-    def wrapper(inner):
-        def decorator(*args, **kwargs):
-            # Fetch the route final url
-            url = route_url(app, controller)
-
-            # check is of type str
-            if type(check) is str:
-                # Check cookie
-                if check_cookie(check):
-                    set_session(check, get_cookie(check))
-
-                # User is logged-in
-                if check_session(check):
-                    return redirect(url)
-
-            # check is of type list
-            elif type(check) is list:
-                for x in check:
-                    # Check cookie
-                    if check_cookie(x):
-                        set_session(x, get_cookie(x))
-
-                    # User is logged-in
-                    if check_session(x):
-                        return redirect(url)
-
-            # User is not logged-in
-            return inner(*args, **kwargs)
-
-        return decorator
-    return wrapper
-
-
+#####################
+# Password Security #
+#####################
 ##
 # @desc Hashing password
 # 
-# @param password: str
+# @param {str} password -- The password to hash
 #
-# @return str
+# @return {str}
 ##
 def hash_password(password):
     return generate_password_hash(password)
@@ -390,10 +361,10 @@ def hash_password(password):
 ##
 # @desc Validates a hashed password
 # 
-# @param hashed_password: str -- Hashed password from database
-# @param requested_password: str -- Requested password by the user
+# @param {str} hashed_password    -- Hashed password from database
+# @param {str} requested_password -- Requested password by the user
 #
-# @return bool
+# @return {bool}
 ##
 def validate_password(hashed_password, requested_password):
     # Valid password
@@ -408,18 +379,19 @@ def validate_password(hashed_password, requested_password):
 ##
 # @desc Checks a password strength
 # 
-# @param password: str   -- The password to validate
-# @param length: int     -- The password minimum length
-# @param digit: bool     -- Check for digit?
-# @param uppercase: bool -- Check for uppercase?
-# @param lowercase: bool -- Check for lowercase?
-# @param symbol: bool    -- Check for symbol?
+# @param {str}  password  -- The password to validate
+# @param {int}  length    -- The password minimum length
+# @param {bool} digit     -- Check for digit?
+# @param {bool} uppercase -- Check for uppercase?
+# @param {bool} lowercase -- Check for lowercase?
+# @param {bool} symbol    -- Check for symbol?
 #
 # @return dict
 ##
 def password_strength(password:str, length:int=8, digit:bool=True, uppercase:bool=True, lowercase:bool=True, symbol:bool=True):
     """
-        A strong password should:
+        With all parameters provided,
+        The password should:
         - Be greater than or equal to `length`
         - Contain one digit or more
         - Contain one uppercase letter or more
@@ -456,10 +428,13 @@ def password_strength(password:str, length:int=8, digit:bool=True, uppercase:boo
     }
 
 
+##############
+# IP Methods #
+##############
 ##
 # @desc Returns the server IP
 #
-# @retun str
+# @retun {str}
 ##
 def server_ip():
     return request.remote_addr
@@ -468,9 +443,9 @@ def server_ip():
 ##
 # @desc Returns the client IP
 # 
-# @param strict: bool -- If True, returns the client's public IP, not a private IP behind a proxy
+# @param {bool} strict -- If True, returns the client's public IP, not a private IP behind a proxy
 #
-# @retun str
+# @retun {str}
 ##
 def client_ip(strict:bool=True):
     # Client is behind a proxy (strict mod)
@@ -480,3 +455,50 @@ def client_ip(strict:bool=True):
     # Client doesn't use proxy
     else:
         return request.environ['REMOTE_ADDR']
+
+
+#################
+# Other Methods #
+#################
+##
+# @desc Finds active language
+# 
+# @var {str} active_lang -- The active language code
+#
+# @return {str}
+##
+def find_lang():
+    path = request.path
+    lang = path.split('/')[1]
+
+    # Check multi language
+    if multi_lang:
+        # Check the language path
+        if lang in languages:
+            active_lang = lang
+            LANGUAGE = '/' + active_lang
+            set_session('active_lang', lang)
+
+        elif check_cookie('active_lang'):
+            active_lang = get_cookie('active_lang')
+            LANGUAGE = '/' + active_lang
+            set_session('active_lang', get_cookie('active_lang'))
+
+        elif check_session('active_lang'):
+            active_lang = get_session('active_lang')
+            LANGUAGE = '/' + active_lang
+
+        else:
+            active_lang = default_lang
+            LANGUAGE = '/' + active_lang
+            set_session('active_lang', default_lang)
+
+    else:
+        active_lang = default_lang
+        LANGUAGE = ''
+
+    # Return result
+    return {
+        'active_language': active_lang,
+        'LANGUAGE': LANGUAGE,
+    }
